@@ -31,7 +31,6 @@
 #include <QXmlSimpleReader>
 #include <QXmlDefaultHandler>
 #include <QXmlInputSource>
-#include <QXmlInputSource>
 
 #include <KCompressionDevice>
 #include <KProcess>
@@ -45,7 +44,7 @@ class IconsParserHandler : public QXmlDefaultHandler
 public:
     IconsParserHandler();
     bool startElement(const QString &namespaceURI, const QString &localName,
-                      const QString &qName, const QXmlAttributes &atts) Q_DECL_OVERRIDE;
+                      const QString &qName, const QXmlAttributes &atts) override;
     QStringList m_ids;
     QStringList m_prefixes;
 };
@@ -264,7 +263,7 @@ void ThemeModel::editElement(const QString& imagePath)
     //TODO: don't use the script to not depend from bash/linux?
     process->setProgram("bash", QStringList() << m_package.filePath("scripts", "openInEditor.sh") << finalFile);
 
-    connect(process, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(processFinished()));
+    connect(process, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(processFinished()));
     process->start();
 }
 
